==> haskell-data-textual-0.3.0.2-100-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-HtA1CN0Nn263g7UcFx1LFw
key: data-textual-0.3.0.2-HtA1CN0Nn263g7UcFx1LFw
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
abi: 1910eaa2d39146b05a0ce26f186a9107
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-HtA1CN0Nn263g7UcFx1LFw
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    parsers-0.12.10-1IdUHQeo46BampZFlmMwV text-1.2.3.1
    text-latin1-0.3.1-F9gMENqLhQUKEeqgV2t8rB
    text-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.2-103-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-textual
version: 0.3.0.2
id: data-textual-0.3.0.2-2ZRQDAMr4IiB0hF0W3hGnr
key: data-textual-0.3.0.2-2ZRQDAMr4IiB0hF0W3hGnr
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-textual
synopsis: Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.
category: Data, Text
abi: 65979099fc69997feb4c0c54af95c32a
exposed: True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-textual-0.3.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-textual-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-textual-0.3.0.2
hs-libraries: HSdata-textual-0.3.0.2-2ZRQDAMr4IiB0hF0W3hGnr
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    parsers-0.12.10-KOAf7LSEBghE1cBkw6ZYub text-1.2.3.1
    text-latin1-0.3.1-F9gMENqLhQUKEeqgV2t8rB
    text-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
haddock-interfaces: /usr/share/doc/haskell-data-textual/html/data-textual.haddock
haddock-html: /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
